Index: components/mus/public/cpp/tests/mandoline_ui_services_test_base.h |
diff --git a/components/mus/public/cpp/tests/view_manager_test_base.h b/components/mus/public/cpp/tests/mandoline_ui_services_test_base.h |
similarity index 62% |
rename from components/mus/public/cpp/tests/view_manager_test_base.h |
rename to components/mus/public/cpp/tests/mandoline_ui_services_test_base.h |
index 15a802c9010096229861c4a81915f56f9c273523..4ab37ae4dcd3d0e85e2fa6c7a4f9be60d29de6d9 100644 |
--- a/components/mus/public/cpp/tests/view_manager_test_base.h |
+++ b/components/mus/public/cpp/tests/mandoline_ui_services_test_base.h |
@@ -2,8 +2,8 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef COMPONENTS_MUS_PUBLIC_CPP_TESTS_VIEW_MANAGER_TEST_BASE_H_ |
-#define COMPONENTS_MUS_PUBLIC_CPP_TESTS_VIEW_MANAGER_TEST_BASE_H_ |
+#ifndef COMPONENTS_MUS_PUBLIC_CPP_TESTS_MANDOLINE_UI_SERVICES_TEST_BASE_H_ |
+#define COMPONENTS_MUS_PUBLIC_CPP_TESTS_MANDOLINE_UI_SERVICES_TEST_BASE_H_ |
#include "base/memory/scoped_ptr.h" |
#include "components/mus/public/cpp/view_tree_delegate.h" |
@@ -13,19 +13,22 @@ |
#include "mojo/application/public/cpp/application_test_base.h" |
#include "mojo/application/public/cpp/interface_factory.h" |
-namespace mojo { |
+namespace mus { |
-// ViewManagerTestBase is a base class for use with app tests that use |
-// ViewManager. SetUp() connects to the ViewManager and blocks until OnEmbed() |
-// has been invoked. window_manager() can be used to access the ViewManager |
+// MandolineUIServicesTestBase is a base class for use with app tests that use |
+// MandolineUIServices. SetUp() connects to the MandolineUIServices and blocks |
+// until OnEmbed() |
+// has been invoked. window_manager() can be used to access the |
+// MandolineUIServices |
// established as part of SetUp(). |
-class ViewManagerTestBase : public test::ApplicationTestBase, |
sky
2015/09/15 21:51:56
This test is targeted at the ViewManager. I would
Fady Samuel
2015/09/15 22:18:50
Done.
|
- public ApplicationDelegate, |
- public ViewTreeDelegate, |
- public InterfaceFactory<ViewTreeClient> { |
+class MandolineUIServicesTestBase |
+ : public mojo::test::ApplicationTestBase, |
+ public mojo::ApplicationDelegate, |
+ public ViewTreeDelegate, |
+ public mojo::InterfaceFactory<mojo::ViewTreeClient> { |
public: |
- ViewManagerTestBase(); |
- ~ViewManagerTestBase() override; |
+ MandolineUIServicesTestBase(); |
+ ~MandolineUIServicesTestBase() override; |
// True if ViewTreeDelegate::OnConnectionLost() was called. |
bool view_tree_connection_destroyed() const { |
@@ -53,25 +56,26 @@ class ViewManagerTestBase : public test::ApplicationTestBase, |
void TearDown() override; |
// test::ApplicationTestBase: |
- ApplicationDelegate* GetApplicationDelegate() override; |
+ mojo::ApplicationDelegate* GetApplicationDelegate() override; |
// ApplicationDelegate: |
- bool ConfigureIncomingConnection(ApplicationConnection* connection) override; |
+ bool ConfigureIncomingConnection( |
+ mojo::ApplicationConnection* connection) override; |
// ViewTreeDelegate: |
void OnEmbed(View* root) override; |
void OnConnectionLost(ViewTreeConnection* connection) override; |
// InterfaceFactory<ViewTreeClient>: |
- void Create(ApplicationConnection* connection, |
- InterfaceRequest<ViewTreeClient> request) override; |
+ void Create(mojo::ApplicationConnection* connection, |
+ mojo::InterfaceRequest<mojo::ViewTreeClient> request) override; |
// Used to receive the most recent view tree connection loaded by an embed |
// action. |
ViewTreeConnection* most_recent_connection_; |
private: |
- ViewTreeHostPtr host_; |
+ mojo::ViewTreeHostPtr host_; |
// The View Manager connection held by the window manager (app running at the |
// root view). |
@@ -79,9 +83,9 @@ class ViewManagerTestBase : public test::ApplicationTestBase, |
bool view_tree_connection_destroyed_; |
- MOJO_DISALLOW_COPY_AND_ASSIGN(ViewManagerTestBase); |
+ MOJO_DISALLOW_COPY_AND_ASSIGN(MandolineUIServicesTestBase); |
}; |
-} // namespace mojo |
+} // namespace mus |
-#endif // COMPONENTS_MUS_PUBLIC_CPP_TESTS_VIEW_MANAGER_TEST_BASE_H_ |
+#endif // COMPONENTS_MUS_PUBLIC_CPP_TESTS_MANDOLINE_UI_SERVICES_TEST_BASE_H_ |